import { __assign } from './../external/tslib/tslib.es6.js';
import * as React from 'react';
import colorTokens from '@highlight-ui/tokens/dist/colors.json';
import { parseMetadata } from '@highlight-ui/utils-commons';
import styles from './CircularProgress.module.scss.js';
var WIDTH = 22;
var STROKE_WIDTH = 3;
var RADIUS = (WIDTH - STROKE_WIDTH * 2) / 2;
var VIEWBOX = "0 0 " + WIDTH + " " + WIDTH;
var CIRCUMFERENCE = RADIUS * Math.PI * 2; // dashlength should cover the whole circumference of the circle

function CircularProgressWithRef(_a, ref) {
  var metadata = _a.metadata,
      percentage = _a.percentage,
      color = _a.color;
  var percentageNum = Math.abs(Number(percentage));
  var finalPercentage = percentageNum > 100 ? 100 : percentageNum;
  var dashOffset = CIRCUMFERENCE - CIRCUMFERENCE * finalPercentage / 100; // Scale 100% coverage overlay with the actual percent

  var halfWidth = WIDTH / 2;
  return /*#__PURE__*/React.createElement("div", {
    "aria-valuemax": 100,
    "aria-valuemin": 0,
    "aria-valuenow": percentageNum,
    role: "progressbar",
    ref: ref
  }, /*#__PURE__*/React.createElement("svg", __assign({}, parseMetadata(metadata), {
    width: WIDTH,
    height: WIDTH,
    viewBox: VIEWBOX
  }), /*#__PURE__*/React.createElement("circle", {
    className: styles.circle,
    cx: halfWidth,
    cy: halfWidth,
    r: RADIUS,
    strokeWidth: STROKE_WIDTH + "px",
    fill: "none"
  }), /*#__PURE__*/React.createElement("circle", {
    className: styles.progressIndicator,
    cx: halfWidth,
    cy: halfWidth,
    r: RADIUS,
    fill: "none",
    strokeWidth: STROKE_WIDTH + "px",
    transform: "rotate(-90 " + halfWidth + " " + halfWidth + ")",
    style: {
      stroke: color && colorTokens[color],
      strokeDasharray: CIRCUMFERENCE,
      strokeDashoffset: dashOffset
    }
  })));
}

var CircularProgress = /*#__PURE__*/React.forwardRef(CircularProgressWithRef);
export { CircularProgress as default };
//# sourceMappingURL=CircularProgress.js.map
